# spatialist
[![Linux Build Status][1]][2] [![Windows Build status][3]][4] [![Coverage Status][5]][6]
[![Documentation Status][7]][8] [![PyPI version][12]][13] [![Conda Version][15]][16]

### A Python module for spatial data handling

This package offers functionalities for user-friendly geo data processing using GDAL and OGR.

### Documentation
A description of spatialist's functionality can be found [here][8].

### Installation
Detailed instructions can be found in the documentation [here][14].

### Tutorial
A jupyter notebook and test data are available [here][11].

[1]: https://www.travis-ci.com/johntruckenbrodt/spatialist.svg?branch=master
[2]: https://www.travis-ci.com/johntruckenbrodt/spatialist
[3]: https://ci.appveyor.com/api/projects/status/3nxj2nnmp21ig860?svg=true
[4]: https://ci.appveyor.com/project/johntruckenbrodt/spatialist
[5]: https://coveralls.io/repos/github/johntruckenbrodt/spatialist/badge.svg?branch=master
[6]: https://coveralls.io/github/johntruckenbrodt/spatialist?branch=master
[7]: https://readthedocs.org/projects/spatialist/badge/?version=latest
[8]: https://spatialist.readthedocs.io/en/latest/?badge=latest
[11]: https://github.com/johntruckenbrodt/spatialist_explorer
[12]: https://badge.fury.io/py/spatialist.svg
[13]: https://badge.fury.io/py/spatialist
[14]: https://spatialist.readthedocs.io/en/latest/installation.html
[15]: https://img.shields.io/conda/vn/conda-forge/spatialist.svg
[16]: https://anaconda.org/conda-forge/spatialist